| conn_info | R Documentation |
Queries the active connection for the library version and platform string.
The two values together identify the subdirectory path used by the extension
repositories, e.g. v1.2.0/osx_arm64/.
conn_info(conn = conn_default())
conn |
A DuckDB connection. Defaults to |
A named list with elements version (e.g. "v1.2.0") and
platform (e.g. "osx_arm64").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.