ensure_azure_exts: Ensure Azure-related extensions are loaded

View source: R/datasets.R

ensure_azure_extsR Documentation

Ensure Azure-related extensions are loaded

Description

Loads the azure extension and, optionally, the delta extension on conn. Does not auto-install.

Usage

ensure_azure_exts(conn, delta = FALSE)

Arguments

conn

A DuckDB connection.

delta

Logical. Also load the delta extension.

Value

Invisibly returns NULL; called for its side effect of loading the azure (and optionally delta) extension onto conn.


quak documentation built on June 9, 2026, 5:09 p.m.