| az_glimpse | R Documentation |
Prints a small preview and invisibly returns it as a tibble-like data frame.
az_glimpse(conn, url, n = 10, format = NULL)
conn |
A DuckDB connection. |
url |
Character scalar. Azure Blob URL. |
n |
Number of rows to preview. Default |
format |
Optional format override. One of |
Invisibly returns the preview tibble-like data frame.
## Not run:
# Requires a live Azure account, credentials, and network access.
conn <- az_conn()
az_glimpse(conn, "abfss://container@account/data/*.parquet", n = 5)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.