| ext_list_available | R Documentation |
Returns the full catalog of extensions maintained by the DuckDB core team, regardless of whether they are installed.
ext_list_available(conn = conn_default())
conn |
A DuckDB connection. Defaults to |
A tibble::tibble() with columns: name, version, description.
conn <- DBI::dbConnect(duckdb::duckdb())
ext_list_available(conn)
DBI::dbDisconnect(conn, shutdown = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.