| ext_load | R Documentation |
When path is supplied, executes LOAD '/path/to/ext.duckdb_extension'
directly — no install check or auto-install occurs. When only name is
supplied, returns immediately if the extension is already loaded. Otherwise
it checks whether the extension is installed; if not and
auto_install = TRUE, installs it (prompting first when ask = TRUE and
the session is interactive), then executes LOAD <name>.
ext_load(
name = NULL,
path = NULL,
conn = conn_default(),
auto_install = TRUE,
ask = rlang::is_interactive(),
cache = ext_cache(),
repo = c("core", "community")
)
name |
Character scalar. Extension name. When |
path |
Optional character scalar. Path to a local
|
conn |
A DuckDB connection. Defaults to |
auto_install |
Logical. Install automatically when the extension is
missing. Default |
ask |
Logical. Prompt the user before installing. Defaults to
|
cache |
An |
repo |
|
Invisibly returns conn.
## Not run:
# Requires network access to download and load the extension.
conn <- DBI::dbConnect(duckdb::duckdb())
ext_load("httpfs", conn = conn)
DBI::dbDisconnect(conn, shutdown = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.