Renders one row per option with its current (resolved) value, the source that value came from, the environment variable that can override it (and whether it is set), and the built-in default.
Usage
# S3 method for class 'quak_opts'
print(x, mask = TRUE, ...)